summaryrefslogtreecommitdiffstats
path: root/src/reportdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/reportdialog.h')
-rw-r--r--src/reportdialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/reportdialog.h b/src/reportdialog.h
index ea0579e..ee05e45 100644
--- a/src/reportdialog.h
+++ b/src/reportdialog.h
@@ -37,10 +37,10 @@ public:
/**
* The constructor sets up the dialog.
*
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- ReportDialog(TQWidget* tqparent, const char* name=0);
+ ReportDialog(TQWidget* parent, const char* name=0);
virtual ~ReportDialog();
public slots:
@@ -37,10 +37,10 @@ public:
* The constructor sets up the dialog.
*
- * @param tqparent A pointer to the tqparent widget
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/